@@ -2,6 +2,7 @@ from typing import Any, Dict, List
 
 import pkg_resources
 
+from fastapi.encoders import jsonable_encoder
 from kisters.network_store.model_library.base import BaseElement
 
 _object_parsers = {}
@@ -21,7 +22,7 @@ for entry_point in pkg_resources.iter_entry_points(
     all_nodes.extend(ep.all_nodes.values())
 
 
-def parse_object(obj: Dict[str, Any]) -> BaseElement:
+def element_from_dict(obj: Dict[str, Any]) -> BaseElement:
     domain = obj.get("domain")
     if not domain:
         raise ValueError("Cannot instantiate: missing attribute 'domain'")
@@ -31,3 +32,7 @@ def parse_object(obj: Dict[str, Any]) -> BaseElement:
             f"Cannot instantiate: attribute 'domain' value {domain} not recognized"
         )
     return parser(obj)
+
+
+def element_to_dict(elem: BaseElement) -> Dict[str, Any]:
+    return jsonable_encoder(elem, include_none=False)
